#
# spec file for package go1.15
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


# strip will cause Go's .a archives to become invalid because strip appears to
# reassemble the archive incorrectly. This is a known issue upstream
# (https://github.com/golang/go/issues/17890), but we have to deal with it in
# the meantime.
%undefine _build_create_debug
%define __arch_install_post export NO_BRP_STRIP_DEBUG=true NO_BRP_AR=true

%if 0%{?suse_version} == 1315
%define gcc_go_version 6
%define go_bootstrap_version go1.4
%else
%ifarch riscv64
%define go_bootstrap_version go1.14
%else
%define go_bootstrap_version go1.9
%endif
%if 0%{?sle_version} == 150000
# SLE15 or Leap 15.x
%define gcc_go_version 7
%else
%define gcc_go_version 9
%endif
%endif

# By default use go and not gccgo
%bcond_with    gccgo

# The fallback boostrap method via %%{go_bootstrap_version} would work for Leap
# but we don't have %%{go_bootstrap_version} in there. Same for SLE15+
#if ( 0%{?suse_version} < 1550 && 0%{?is_opensuse} ) || ( 0%{?suse_version} >= 1500 && ! 0%{?is_opensuse} )
#bcond_without gccgo
#endif

# The fallback bootstrap method via go1.4 doesn't work
# for aarch64 nor ppc64le because go 1.4 did not support that architecture.
%if 0%{?suse_version} == 1315
%ifarch aarch64 ppc64le ppc64 s390x
%bcond_without gccgo
%endif
%endif

# gccgo on ppc64le with default PIE enabled fails with:
# error while loading shared libraries:
# R_PPC64_ADDR16_HA re10143fb0c for symbol `' out of range
# track https://github.com/golang/go/issues/28531
# linuxppc-dev discussion:
# "PIE binaries are no longer mapped below 4 GiB on ppc64le"
# https://lists.ozlabs.org/pipermail/linuxppc-dev/2018-November/180862.html
%ifarch ppc64le
#!BuildIgnore: gcc-PIE
%endif

# Build go-race only on platforms where it's supported (both amd64 and aarch64
# requires SLE15-or-later because of C++14, and ppc64le doesn't build at all
# on openSUSE yet).
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} >= 150000
%define tsan_arch x86_64 aarch64
%else
# Cannot use {nil} here (ifarch doesn't like it) so just make up a fake
# architecture that no build will ever match.
%define tsan_arch openSUSE_FAKE_ARCH
%endif

# Go has precompiled versions of LLVM's compiler-rt inside their source code.
# We cannot ship pre-compiled binaries so we have to recompile said source,
# however they vendor specific commits from upstream. This value comes from
# src/runtime/race/README (and we verify that it matches in check).
#
# In order to update the TSAN version, modify _service. See boo#1052528 for
# more details.
%define tsan_commit 6c75db8b4bc59eace18143ce086419d37da24746

%define go_api 1.15

# shared library support
%if "%{rpm_vercmp %{go_api} 1.5}" > "0"
%if %{with gccgo}
%define with_shared 1
%else
%ifarch %ix86 %arm x86_64 aarch64
%define with_shared 1
%else
%define with_shared 0
%endif
%endif
%else
%define with_shared 0
%endif
%ifarch ppc64
%define with_shared 0
%endif
# setup go_arch (BSD-like scheme)
%ifarch %ix86
%define go_arch 386
%endif
%ifarch x86_64
%define go_arch amd64
%endif
%ifarch aarch64
%define go_arch arm64
%endif
%ifarch %arm
%define go_arch arm
%endif
%ifarch ppc64
%define go_arch ppc64
%endif
%ifarch ppc64le
%define go_arch ppc64le
%endif
%ifarch s390x
%define go_arch s390x
%endif
%ifarch riscv64
%define go_arch riscv64
%endif

Name:           go1.15
Version:        1.15.15
Release:        3.3
Summary:        A compiled, garbage-collected, concurrent programming language
License:        BSD-3-Clause
Group:          Development/Languages/Other
URL:            http://golang.org
Source:         http://golang.org/dl/go%{version}.src.tar.gz
Source1:        go-rpmlintrc
Source4:        README.SUSE
Source6:        go.gdbinit
# We have to compile TSAN ourselves. boo#1052528
Source100:      llvm-%{tsan_commit}.tar.xz
# PATCH-FIX-OPENSUSE enable writing tools outside $GOROOT/pkg/tool for packaging
Patch5:         tools-packaging.patch
# PATCH-FIX-UPSTREAM marguerite@opensuse.org - find /usr/bin/go-5 when bootstrapping with gcc5-go
Patch8:         gcc6-go.patch
Patch9:         gcc7-go.patch
# PATCH-FIX-UPSTREAM prefer /etc/hosts over DNS when /etc/nsswitch.conf not present boo#1172868 gh#golang/go#35305
Patch12:        go1.x-prefer-etc-hosts-over-dns.patch
Patch13:        reproducible.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# boostrap
%if %{with gccgo}
%ifnarch s390 s390x
BuildRequires:  binutils-gold
%endif
BuildRequires:  gcc%{gcc_go_version}-go
%else
# no gcc-go
BuildRequires:  %{go_bootstrap_version}
%endif
BuildRequires:  fdupes
Recommends:     %{name}-doc = %{version}
%ifarch %{tsan_arch}
# Needed to compile compiler-rt/TSAN.
BuildRequires:  gcc-c++
%endif
#BNC#818502 debug edit tool of rpm fails on i586 builds
BuildRequires:  rpm >= 4.11.1
# Needed on arm aarch64 to avoid
# collect2: fatal error: cannot find 'ld'-
%ifarch %arm aarch64
BuildRequires:  binutils-gold
%endif
Requires(post): update-alternatives
Requires(postun):update-alternatives
# Needed on arm aarch64 to avoid
# collect2: fatal error: cannot find 'ld'-
%ifarch %arm aarch64
%if 0%{?is_opensuse}
Requires:       binutils-gold
%else
Recommends:     binutils-gold
%endif
%endif
Requires:       gcc
Provides:       go = %{version}
Provides:       go-devel = go%{version}
Provides:       go-devel-static = go%{version}
Provides:       golang(API) = %{go_api}
Obsoletes:      go-devel < go%{version}
# go-vim/emacs were separate projects starting from 1.4
Obsoletes:      go-emacs <= 1.3.3
Obsoletes:      go-vim <= 1.3.3
ExclusiveArch:  %ix86 x86_64 %arm aarch64 ppc64 ppc64le s390x riscv64

%description
Go is an expressive, concurrent, garbage collected systems programming language
that is type safe and memory safe. It has pointers but no pointer arithmetic.
Go has fast builds, clean syntax, garbage collection, methods for any type, and
run-time reflection. It feels like a dynamic language but has the speed and
safety of a static language.

%package doc
Summary:        Go documentation
Group:          Documentation/Other
Requires:       %{name} = %{version}
Provides:       go-doc = %{version}

%description doc
Go examples and documentation.

%ifarch %{tsan_arch}
# boo#1052528
%package race
Summary:        Go runtime race detector
Group:          Development/Languages/Other
URL:            https://compiler-rt.llvm.org/
Requires:       %{name} = %{version}
Supplements:    %{name} = %{version}
ExclusiveArch:  %{tsan_arch}

%description race
Go runtime race detector libraries. Install this package if you wish to use the
-race option, in order to detect race conditions present in your Go programs.
%endif

%prep
%ifarch %{tsan_arch}
# compiler-rt (from LLVM)
%setup -q -T -b 100 -n llvm-%{tsan_commit}
%endif
# go
%setup -q -n go
%patch -P 5 -p1
%patch -P 12 -p1
%if %{with gccgo}
%if 0%{?gcc_go_version} == 6
%patch -P 8 -p1
%endif
%if 0%{?gcc_go_version} == 7
%patch -P 9 -p1
%endif
%endif
%patch -P 13 -p1

cp %{SOURCE4} .

%build
# Remove the pre-included .sysos, to avoid shipping things we didn't compile
# (which is against the openSUSE guidelines for packaging).
find . -type f -name '*.syso' -print -delete

# First, compile LLVM's TSAN, and replace the built-in with it. We can only do
# this for amd64.
%ifarch %{tsan_arch}
TSAN_DIR="../llvm-%{tsan_commit}/compiler-rt/lib/tsan/go"
pushd "$TSAN_DIR"
./buildgo.sh
popd
cp -v "$TSAN_DIR/race_linux_%{go_arch}.syso" src/runtime/race/
%endif

# Now, compile Go.
%if %{with gccgo}
export GOROOT_BOOTSTRAP=%{_prefix}
%else
export GOROOT_BOOTSTRAP=%{_libdir}/%{go_bootstrap_version}
%endif
# Ensure ARM arch is set properly - boo#1169832
%ifarch armv6l armv6hl
export GOARCH=arm
export GOARM=6
%endif
%ifarch armv7l armv7hl
export GOARCH=arm
export GOARM=7
%endif
export GOROOT="`pwd`"
export GOROOT_FINAL=%{_libdir}/go/%{go_api}
export GOBIN="$GOROOT/bin"
mkdir -p "$GOBIN"
cd src
HOST_EXTRA_CFLAGS="%{optflags} -Wno-error" ./make.bash -v

cd ../
%ifarch %{tsan_arch}
# Install TSAN-friendly version of the std libraries.
bin/go install -race std
%endif

%if %{with_shared}
bin/go install -buildmode=shared -linkshared std
%endif

%check
%ifarch %{tsan_arch}
# Make sure that we have the right TSAN checked out.
grep "^race_linux_%{go_arch}.syso built with LLVM %{tsan_commit}" src/runtime/race/README
%endif

%install
export GOROOT="%{buildroot}%{_libdir}/go/%{go_api}"

# locations for third party libraries, see README-openSUSE for info about locations.
install -d  %{buildroot}%{_datadir}/go/%{go_api}/contrib
install -d  $GOROOT/contrib/pkg/linux_%{go_arch}
ln -s %{_libdir}/go/%{go_api}/contrib/pkg/ %{buildroot}%{_datadir}/go/%{go_api}/contrib/pkg
install -d  %{buildroot}%{_datadir}/go/%{go_api}/contrib/cmd
install -d  %{buildroot}%{_datadir}/go/%{go_api}/contrib/src
ln -s %{_datadir}/go/%{go_api}/contrib/src/ %{buildroot}%{_libdir}/go/%{go_api}/contrib/src
install -Dm644 README.SUSE $GOROOT/contrib/
ln -s %{_libdir}/go/%{go_api}/contrib/README.SUSE %{buildroot}%{_datadir}/go/%{go_api}/contrib/README.SUSE

# source files for go install, godoc, etc
install -d %{buildroot}%{_datadir}/go/%{go_api}
for ext in *.{go,c,h,s,S,py,syso}; do
  find src -name ${ext} -exec install -Dm644 \{\} %{buildroot}%{_datadir}/go/%{go_api}/\{\} \;
done
mkdir -p $GOROOT/src
for i in $(ls %{buildroot}/usr/share/go/%{go_api}/src);do
  ln -s /usr/share/go/%{go_api}/src/$i $GOROOT/src/$i
done
# add lib files that are needed (such as the timezone database).
install -d $GOROOT/lib
find lib -type f -exec install -D -m644 {} $GOROOT/{} \;

# copy document templates, packages, obj libs and command utilities
mkdir -p $GOROOT/bin
# remove bootstrap
rm -rf pkg/bootstrap
mv pkg $GOROOT
mv bin/* $GOROOT/bin
mkdir -p $GOROOT/misc/trace
mv misc/trace/* $GOROOT/misc/trace
# add wasm (Web Assembly) boo#1139210
mkdir -p $GOROOT/misc/wasm
mv misc/wasm/* $GOROOT/misc/wasm
rm -f %{buildroot}%{_bindir}/{hgpatch,quietgcc}

# gdbinit
install -Dm644 %{SOURCE6} $GOROOT/bin/gdbinit.d/go.gdb
%if "%{_lib}" == "lib64"
sed -i "s/lib/lib64/" $GOROOT/bin/gdbinit.d/go.gdb
sed -i "s/\$go_api/%{go_api}/" $GOROOT/bin/gdbinit.d/go.gdb
%endif

# update-alternatives
 mkdir -p %{buildroot}%{_sysconfdir}/alternatives
 mkdir -p %{buildroot}%{_bindir}
 mkdir -p %{buildroot}%{_sysconfdir}/profile.d
 mkdir -p %{buildroot}%{_sysconfdir}/gdbinit.d
 touch %{buildroot}%{_sysconfdir}/alternatives/{go,gofmt,go.gdb}
 ln -sf %{_sysconfdir}/alternatives/go %{buildroot}%{_bindir}/go
 ln -sf %{_sysconfdir}/alternatives/gofmt %{buildroot}%{_bindir}/gofmt
 ln -sf %{_sysconfdir}/alternatives/go.gdb %{buildroot}%{_sysconfdir}/gdbinit.d/go.gdb

# documentation and examples
# fix documetation permissions (rpmlint warning)
find doc/ misc/ -type f -exec chmod 0644 '{}' +
# remove unwanted arch-dependant binaries (rpmlint warning)
rm -rf misc/cgo/test/{_*,*.o,*.out,*.6,*.8}
# prepare go-doc
mkdir -p %{buildroot}%{_docdir}/go/%{go_api}
cp -r AUTHORS CONTRIBUTORS CONTRIBUTING.md LICENSE PATENTS README.md README.SUSE %{buildroot}%{_docdir}/go/%{go_api}
cp -r doc/* %{buildroot}%{_docdir}/go/%{go_api}

%fdupes -s %{buildroot}%{_prefix}

%post

update-alternatives \
  --install %{_bindir}/go go %{_libdir}/go/%{go_api}/bin/go $((20+$(echo %{go_api} | cut -d. -f2))) \
  --slave %{_bindir}/gofmt gofmt %{_libdir}/go/%{go_api}/bin/gofmt \
  --slave %{_sysconfdir}/gdbinit.d/go.gdb go.gdb %{_libdir}/go/%{go_api}/bin/gdbinit.d/go.gdb

%postun
if [ $1 -eq 0 ] ; then
	update-alternatives --remove go %{_libdir}/go/%{go_api}/bin/go
fi

%files
%{_bindir}/go
%{_bindir}/gofmt
%dir %{_libdir}/go
%{_libdir}/go/%{go_api}
%dir %{_datadir}/go
%{_datadir}/go/%{go_api}
%dir %{_sysconfdir}/gdbinit.d/
%config %{_sysconfdir}/gdbinit.d/go.gdb
%ghost %{_sysconfdir}/alternatives/go
%ghost %{_sysconfdir}/alternatives/gofmt
%ghost %{_sysconfdir}/alternatives/go.gdb
%dir %{_docdir}/go
%dir %{_docdir}/go/%{go_api}
%doc %{_docdir}/go/%{go_api}/AUTHORS
%doc %{_docdir}/go/%{go_api}/CONTRIBUTORS
%doc %{_docdir}/go/%{go_api}/CONTRIBUTING.md
%doc %{_docdir}/go/%{go_api}/PATENTS
%doc %{_docdir}/go/%{go_api}/README.md
%doc %{_docdir}/go/%{go_api}/README.SUSE
%if 0%{?suse_version} < 1500
%doc %{_docdir}/go/%{go_api}/LICENSE
%else
%license %{_docdir}/go/%{go_api}/LICENSE
%endif

# We don't include TSAN in the main Go package.
%ifarch %{tsan_arch}
%exclude %{_datadir}/go/%{go_api}/src/runtime/race/race_linux_%{go_arch}.syso
%endif

%files doc
%defattr(-,root,root,-)
%doc %{_docdir}/go/%{go_api}/codewalk
%doc %{_docdir}/go/%{go_api}/articles
%doc %{_docdir}/go/%{go_api}/progs
%doc %{_docdir}/go/%{go_api}/play
%doc %{_docdir}/go/%{go_api}/gopher
%doc %{_docdir}/go/%{go_api}/*.html
%doc %{_docdir}/go/%{go_api}/*.css
%doc %{_docdir}/go/%{go_api}/*.png

%ifarch %{tsan_arch}
%files race
%{_datadir}/go/%{go_api}/src/runtime/race/race_linux_%{go_arch}.syso
%endif

%changelog
* Mon Apr 15 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to avoid build-time race (boo#1102408)
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Aug  5 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.15 (released 2021-08-05) includes a security fix to the
  net/http/httputil package, as well as bug fixes to the compiler,
  the runtime, the go command, and the net/http package.
  CVE-2021-36221
  Refs boo#1175132 go1.15 release tracking
  * boo#1189162 go#46866 CVE-2021-36221
  * go#47473 net/http: panic due to racy read of persistConn after handler panic
  * go#47347 cmd/go: "go list -f '{{.Stale}}'" stack overflow with cyclic imports
  * go#47014 cmd/go: go mod vendor: open C:\Users\LICENSE: Access is denied.
  * go#46927 cmd/compile: register conflict between external linker and duffzero on arm64
  * go#46857 runtime: ppc64x binaries randomly segfault on linux 5.13rc6
* Thu Aug  5 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Drop patch to fix crashes on PowerPC with kernel >= 5.13, fixed
  in next upstream release:
  * drop fix-crash-on-ppc64le.patch
* Sun Jul 25 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix go#46803 boo#1188906, add fix-crash-on-ppc64le.patch
* Mon Jul 12 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.14 (released 2021-07-12) includes a security fix to the
  crypto/tls package, as well as bug fixes to the linker, and the
  net package.
  CVE-2021-34558
  Refs boo#1175132 go1.15 release tracking
  * boo#1188229 go#47143 CVE-2021-34558
  * go#47144 security: fix CVE-2021-34558
  * go#47012 net: LookupMX behaviour broken
  * go#46994 net: TestCVE202133195 fails if /etc/resolv.conf specifies ndots larger than 3
  * go#46768 syscall: TestGroupCleanupUserNamespace test failure on Fedora
  * go#46684 x/build/cmd/release: linux-armv6l release tests aren't passing
  * go#46656 runtime: deeply nested struct initialized with non-zero values
* Thu Jun 10 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Fix extraneous trailing percent character %%endif%% in spec file.
* Thu Jun  3 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.13 (released 2021-06-03) includes security fixes to the
  archive/zip, math/big, net, and net/http/httputil packages, as
  well as bug fixes to the linker, the go command, and the math/big
  and net/http packages.
  CVE-2021-33195 CVE-2021-33196 CVE-2021-33197 CVE-2021-33198
  Refs boo#1175132 go1.15 release tracking
  * boo#1187443 go#46241 CVE-2021-33195
  * go#46356 net: Lookup functions may return invalid host names
  * go#46531 net: Unix dnsclient test for CVE-2021-33195 assumes that 1.2.3.4 does not resolve
  * boo#1186622 go#46242 CVE-2021-33196
  * go#46396 archive/zip: malformed archive may cause panic or memory exhaustion
  * boo#1187444 go#46313 CVE-2021-33197
  * go#46314 net/http/httputil: ReverseProxy forwards Connection headers if first one is empty
  * boo#1187445 go#45910 CVE-2021-33198
  * go#46305 math/big: (*Rat).SetString with "1.770p02041010010011001001" crashes with "makeslice: len out of range"
  * go#46143 cmd/go: error out of 'go mod tidy' if the go.mod file specifies a newer-than-supported Go version
  * go#46127 cmd/link: internal error when externally linking very large binaries
  * go#46002 cmd/link: SIGSEGV running 'openshift-install version' for release-4.8 using external linking on PPC64LE
  * go#45335 math/big: Int.Lsh gives wrong results on s390x for n>=128
* Fri May  7 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.12 (released 2021-05-06) includes a security fix to the
  net/http package, as well as bug fixes to the runtime and the
  time package.
  CVE-2021-31525
  Refs boo#1175132 go1.15 release tracking
  * boo#1185790 CVE-2021-31525
  * go#45711 net/http: ReadRequest can stack overflow
  * go#45731 time, runtime: scheduled timer may never fire if GOMAXPROCS is reduced
  * go#45481 runtime: "invalid pc-encoded table" throw caused by bad cgo traceback (expandFinalInlineFrames)
  * go#45384 time: Europe/Dublin timezone handling broken with embedded timezone database
* Fri Apr  2 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.11 (released 2021-04-01) includes fixes to cgo, the
  compiler, linker, runtime, the go command, and the database/sql
  and net/http packages.
  Refs boo#1175132 go1.15 release tracking
  * go#45302 runtime: "invalid pc-encoded table" throw caused by bad cgo traceback
  * go#45239 all: run.{bash,bat,rc} sets GOPATH inconsistently
  * go#45187 Strange behaviour with loops
  * go#45076 net/http: transport caches permanently broken persistent connections if write error happens during h2 handshake
  * go#44872 cmd/go: 'go get' does not add missing hash to go.sum when ziphash file missing from cache
  * go#44748 cmd/link: fail to build when using time/tzdata on ARM
  * go#43592 cmd/link: "x86_64-w64-mingw32/bin/ld.exe: Error: export ordinal too large" after upgrading to Go 1.15
  * go#43591 cmd/link: -buildmode=c-shared exports many functions, not just //export functions
  * go#42884 database/sql: deadlock on transaction stmt context cancel
* Fri Mar 12 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.10 (released 2021-03-11) includes fixes to the compiler,
  the go command, and the net/http, os, syscall, and time packages.
  Refs boo#1175132 go1.15 release tracking
  * go#44792 cmd/go: mod tidy should ignore missing standard library packages
  * go#44658 runtime: marked free object in span
  * go#44617 time: LoadLocationFromTZData with slim tzdata uses incorrect zone
  * go#44592 syscall & x/sys/windows: buffer overflow in GetQueuedCompletionStatus
  * go#44294 net/http: ServeContent()/ServeFile() doesn't return expected response when WriteTimeout happens
  * go#44273 os: copy_file_range system call fails on some file systems
  * go#42935 net/http: Transport race condition by Content-Length == 0 response
  * go#42930 cmd/compile: miscompilation of some arithmetic and conditionals on arm
* Wed Mar 10 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.9 (released 2021-03-10) includes security fixes to the
  encoding/xml package.
  CVE-2021-27918
  Refs boo#1175132 go1.15 release tracking
  * boo#1183333 CVE-2021-27918
  * go#44914 encoding/xml: infinite loop when using `xml.NewTokenDecoder` with a custom `TokenReader`
* Fri Feb  5 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.8 (released 2021-02-04) includes fixes to the compiler,
  linker, runtime, the go command, and the net/http package.
  Refs boo#1175132 go1.15 release tracking
  * go#43861 cmd/go: TestScript/get_update_unknown_protocol test fails
  * go#43860 cmd/go: handle space in path to C compiler
  * go#43833 runtime: SIGSEGV in runtime.deltimer on linux-mips-rtrk during ReadMemStats
  * go#43797 cmd/go: TestScript/mod_get_fallback relies on x/tools not being tagged
  * go#43793 internal/execabs: disable tests on js-wasm
  * go#43575 cmd/compile: 32-bit random data corruption
  * go#43406 x/mobile/cmd/gomobile: gomobile build on simple program returns "ld: error: duplicate symbol: x_cgo_inittls"
  * go#43214 cmd/link: panic: runtime error: slice bounds out of range [::1751306] with length 1048576
  * go#42539 net/http: race in http2Transport
  * go#42384 cmd/link: PE linker segfaults in addpersrc when cross-compiling
* Tue Jan 19 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.7 (released 2021-01-19) includes security fixes to the
  go command and crypto/elliptic package.
  CVE-2021-3114 CVE-2021-3115
  Refs boo#1175132 go1.15 release tracking
  * boo#1181145 CVE-2021-3114
  * go#43788 crypto/elliptic: incorrect operations on the P-224 curve
  * boo#1181146 CVE-2021-3115
  * go#43785 cmd/go: packages using cgo can cause arbitrary code execution on Windows
* Thu Dec  3 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.6 (released 2020-12-03) includes fixes to the compiler,
  linker, runtime, the go command, and the io package.
  Refs boo#1175132 go1.15 release tracking
  * go#42948 cmd/link: unexpected bindingNone in '_go.buildid'
  * go#42753 cmd/compile: ICE due to bad ORL constant
  * go#42636 runtime: infinite loop in lockextra on linux/amd64
  * go#42567 cmd/go: allow flags in CGO_LDFLAGS environment variable not in security allowlist
  * go#42550 io: Copy leaves file zero bytes in Azure AKS with CIFS - Go1.15 regression
  * go#42521 cmd/link: debug_line can contain multiple entries for the same PC address in Go 1.15.4
  * go#42369 internal/poll: CopyFileRange returns EIO on CentOS 7 ( Linux Kernel 3.10.0-1127) when io.Copy in mounted CIFS
* Thu Nov 12 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.5 (released 2020-11-12) includes security fixes to the
  cmd/go and math/big packages.
  CVE-2020-28362 CVE-2020-28367 CVE-2020-28366
  Refs boo#1175132 go1.15 release tracking
  * boo#1178750 CVE-2020-28362
  * go#42554 math/big: panic during recursive division of very large numbers
  * boo#1178752 CVE-2020-28367
  * go#42562 cmd/go: arbitrary code can be injected into cgo generated files
  * boo#1178753 CVE-2020-28366
  * go#42558 cmd/go: improper validation of cgo flags can lead to remote code execution at build time
* Fri Nov  6 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.4 (released 2020-11-05) includes fixes to cgo, the
  compiler, linker, runtime, and the compress/flate, net/http,
  reflect, and time packages.
  Refs boo#1175132 go1.15 release tracking
  * go#42169 cmd/compile, runtime, reflect: pointers to go:notinheap types must be stored indirectly in interfaces
  * go#42151 cmd/cgo: opaque struct pointers are broken since Go 1.15.3
  * go#42138 time: Location interprets wrong timezone (DST) with slim zoneinfo
  * go#42113 x/net/http2: the first write error on a connection will cause all subsequent write requests to fail blindly
  * go#41914 net/http: request.Clone doesn't deep copy TransferEncoding
  * go#41704 runtime: macOS syscall.Exec can get SIGILL due to preemption signal
  * go#41463 compress/flate: deflatefast produces corrupted output
  * go#41387 x/net/http2: connection-level flow control not returned if stream errors, causes server hang
  * go#40974 cmd/link: sectionForAddress(0xA9D67F) address not in any section file
* Thu Oct 15 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.3 (released 2020-10-14) includes fixes to cgo, the
  compiler, runtime, the go command, and the bytes, plugin, and
  testing packages.
  Refs boo#1175132 go1.15 release tracking
  * go#41871 cmd/cgo: support other GOARCH values in 1.15
  * go#41797 runtime: memory corruption from stack-allocated defer on 32-bit
  * go#41720 cmd/compile: invalid instruction: MOVL $11553462026240, AX
  * go#41620 memory corruption on linux/386 with float32 arithmetic, GO386=387, buildmode pie/c-archive
  * go#41595 internal/bytealg: SIGILL on s390x [1.15 backport] CherryPickApproved
  * go#41543 cmd/compile: 1.15 heap allocations regression when calling Write on os.Stdout
  * go#41464 cmd/go: breakage with go version command and GOFLAGS environment variable
  * go#41453 cmd/addr2line: TestAddr2Line fails with double / in $GOROOT_FINAL
  * go#41432 cmd/cgo: jmethodID/jfieldID is not mapped to uintptr if building with the Android NDK
  * go#41317 runtime: "fatal error: unexpected signal during runtime execution" on windows-amd64-longtest builder of Go 1.15.2 commit
  * go#40881 testing: summary and test output interleaved
  * go#40742 runtime: pcdata is -2 and 12 locals stack map entries error on nil pointer
  * go#40693 plugin: program on linux/s390x sometimes hangs after calling "plugin.Open"
  * go#40643 runtime: race between stack shrinking and channel send/recv leads to bad sudog values
* Wed Sep  9 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.2 (released 2020-09-09) includes fixes to the compiler,
  runtime, documentation, the go command, and the net/mail, os,
  sync, and testing packages.
  Refs boo#1175132 go1.15 release tracking
  * go#41193 net/http/fcgi: race detected during execution of TestResponseWriterSniffsContentType test
  * go#41178 doc: include fix for #34437 in Go 1.14 release notes
  * go#41034 testing: Cleanup races with Logf and Errorf
  * go#41011 sync: sync.Map keys will never be garbage collected
  * go#40934 runtime: checkptr incorrectly -race flagging when using &^ arithmetic
  * go#40900 internal/poll: CopyFileRange returns EPERM on CircleCI Docker Host running 4.10.0-40-generic
  * go#40868 cmd/compile: R12 can be clobbered for write barrier call on PPC64
  * go#40849 testing: "=== PAUSE" lines do not change the test name for the next log line
  * go#40845 runtime: Panic if newstack at runtime.acquireLockRank
  * go#40805 cmd/test2json: tests that panic are marked as passing
  * go#40804 net/mail: change in behavior of ParseAddressList("") in 1.15
  * go#40802 cmd/go: in 1.15: change in "go test" argument parsing
  * go#40798 cmd/compile: inline marker targets not reachable after assembly on arm
  * go#40772 cmd/compile: compiler crashes in ssa: isNonNegative bad type
  * go#40767 cmd/compile: inline marker targets not reachable after assembly on ppc64x
  * go#40739 internal/poll: CopyFileRange returns ENOTSUP on Linux 3.10.0 kernel on NFS mount
  * go#40412 runtime: Windows service lifecycle events behave incorrectly when called within a golang environment
- Add missing '?' before 'suse_version' test by Xia Lei <emricg2@gmail.com>
* Fri Sep  4 2020 Marcus Meissner <meissner@suse.com>
- replace binutils-gold requires by recommends for aarch64 on SLE. (bsc#1170826)
* Tue Sep  1 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15.1 (released 2020-09-01) includes security fixes to the
  net/http/cgi and net/http/fcgi packages.
  CVE-2020-24553
  Refs boo#1175132 go1.15 release tracking
  * boo#1176031 CVE-2020-24553
  * go#41165 net/http/cgi,net/http/fcgi: Cross-Site Scripting (XSS) when Content-Type is not specified
* Tue Aug 11 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15 (released 2020-08-11) Go 1.15 is a major release of Go.
  go1.15.x minor releases will be provided through August 2021.
  https://github.com/golang/go/wiki/Go-Release-Cycle
  Most changes are in the implementation of the toolchain, runtime,
  and libraries. As always, the release maintains the Go 1 promise
  of compatibility. We expect almost all Go programs to continue to
  compile and run as before.
  Refs boo#1175132 go1.15 release tracking
  * See release notes https://golang.org/doc/go1.15. Excerpts
    relevant to OBS environment and for SUSE/openSUSE follow:
  * Module support in the go command is ready for production use,
    and we encourage all users to migrate to Go modules for
    dependency management.
  * Module cache: The location of the module cache may now be set
    with the GOMODCACHE environment variable. The default value of
    GOMODCACHE is GOPATH[0]/pkg/mod, the location of the module
    cache before this change.
  * Compiler flag parsing: Various flag parsing issues in go test
    and go vet have been fixed. Notably, flags specified in
    GOFLAGS are handled more consistently, and the -outputdir flag
    now interprets relative paths relative to the working
    directory of the go command (rather than the working directory
    of each individual test).
  * The GOPROXY environment variable now supports skipping proxies
    that return errors. Proxy URLs may now be separated with
    either commas (,) or pipe characters (|). If a proxy URL is
    followed by a comma, the go command will only try the next
    proxy in the list after a 404 or 410 HTTP response. If a proxy
    URL is followed by a pipe character, the go command will try
    the next proxy in the list after any error. Note that the
    default value of GOPROXY remains
    https://proxy.golang.org,direct, which does not fall back to
    direct in case of errors.
  * On a Unix system, if the kill command or kill system call is
    used to send a SIGSEGV, SIGBUS, or SIGFPE signal to a Go
    program, and if the signal is not being handled via
    os/signal.Notify, the Go program will now reliably crash with
    a stack trace. In earlier releases the behavior was
    unpredictable.
  * Allocation of small objects now performs much better at high
    core counts, and has lower worst-case latency.
  * Go 1.15 reduces typical binary sizes by around 5%% compared to
    Go 1.14 by eliminating certain types of GC metadata and more
    aggressively eliminating unused type metadata.
  * The toolchain now mitigates Intel CPU erratum SKX102 on
    GOARCH=amd64 by aligning functions to 32 byte boundaries and
    padding jump instructions. While this padding increases binary
    sizes, this is more than made up for by the binary size
    improvements mentioned above.
  * Go 1.15 adds a -spectre flag to both the compiler and the
    assembler, to allow enabling Spectre mitigations. These should
    almost never be needed and are provided mainly as a "defense
    in depth" mechanism. See the Spectre Go wiki page for details.
  * The compiler now rejects //go: compiler directives that have
    no meaning for the declaration they are applied to with a
    "misplaced compiler directive" error. Such misapplied
    directives were broken before, but were silently ignored by
    the compiler.
  * Substantial improvements to the Go linker, which reduce linker
    resource usage (both time and memory) and improve code
    robustness/maintainability. Linking is 20%% faster and requires
    30%% less memory on average. These changes are part of a
    multi-release project to modernize the Go linker, meaning that
    there will be additional linker improvements expected in
    future releases.
  * The linker now defaults to internal linking mode for
  - buildmode=pie on linux/amd64 and linux/arm64, so these
    configurations no longer require a C linker.
  * There has been progress in improving the stability and
    performance of the 64-bit RISC-V port on Linux (GOOS=linux,
    GOARCH=riscv64). It also now supports asynchronous preemption.
  * crypto/x509: The deprecated, legacy behavior of treating the
    CommonName field on X.509 certificates as a host name when no
    Subject Alternative Names are present is now disabled by
    default. It can be temporarily re-enabled by adding the value
    x509ignoreCN=0 to the GODEBUG environment variable. Note that
    if the CommonName is an invalid host name, it's always
    ignored, regardless of GODEBUG settings. Invalid names include
    those with any characters other than letters, digits, hyphens
    and underscores, and those with empty labels or trailing dots.
  * crypto/x509: go1.15 applications with an AWS DB instance that
    was created or updated to the rds-ca-2019 certificate prior to
    July 28, 2020, you must update the certificate again. If you
    created your DB instance or updated its certificate after July
    28, 2020, no action is required. For more information, see
    go#39568
* Fri Aug  7 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15rc2 (released 2020-08-07) is a release candidate of go1.15
  cut from the master branch at the revision tagged go1.15rc2.
* Fri Jul 24 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15rc1 (released 2020-07-24) is a release candidate of go1.15
  cut from the master branch at the revision tagged go1.15rc1.
* Fri Jun 12 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.15beta1 (released 2020-06-11) is a beta version of go1.15 cut
  from the master branch at the revision tagged go1.15beta1.
